@@ -17,13 +17,13 @@ from .description import (
     unregister_description,
 )
 from .did_you_mean import did_you_mean
-from .event_emitter import EventEmitter, EventEmitterAsyncIterator
 from .identity_func import identity_func
 from .inspect import inspect
 from .is_awaitable import is_awaitable
 from .is_collection import is_collection
 from .is_finite import is_finite
 from .is_integer import is_integer
+from .natural_compare import natural_comparison_key
 from .awaitable_or_value import AwaitableOrValue
 from .suggestion_list import suggestion_list
 from .frozen_error import FrozenError
@@ -31,6 +31,7 @@ from .frozen_list import FrozenList
 from .frozen_dict import FrozenDict
 from .path import Path
 from .print_path_list import print_path_list
+from .simple_pub_sub import SimplePubSub, SimplePubSubIterator
 from .undefined import Undefined, UndefinedType
 
 __all__ = [
@@ -42,14 +43,13 @@ __all__ = [
     "is_description",
     "register_description",
     "unregister_description",
-    "EventEmitter",
-    "EventEmitterAsyncIterator",
     "identity_func",
     "inspect",
     "is_awaitable",
     "is_collection",
     "is_finite",
     "is_integer",
+    "natural_comparison_key",
     "AwaitableOrValue",
     "suggestion_list",
     "FrozenError",
@@ -57,6 +57,8 @@ __all__ = [
     "FrozenDict",
     "Path",
     "print_path_list",
+    "SimplePubSub",
+    "SimplePubSubIterator",
     "Undefined",
     "UndefinedType",
 ]
