@@ -1,4 +1,4 @@
-from asyncio import CancelledError, Event, Future, ensure_future, wait
+from asyncio import CancelledError, Event, Task, ensure_future, wait
 from concurrent.futures import FIRST_COMPLETED
 from inspect import isasyncgen, isawaitable
 from typing import cast, Any, AsyncIterable, Callable, Optional, Set, Type, Union
@@ -46,7 +46,7 @@ class MapAsyncIterator:
             anext = ensure_future(self.iterator.__anext__())
 
             try:
-                pending: Set[Future] = (
+                pending: Set[Task] = (
                     await wait([aclose, anext], return_when=FIRST_COMPLETED)
                 )[1]
             except CancelledError:
