@@ -243,6 +243,11 @@ __Type: GraphQLObjectType = GraphQLObjectType(
         ),
         "inputFields": GraphQLField(
             GraphQLList(GraphQLNonNull(__InputValue)),
+            args={
+                "includeDeprecated": GraphQLArgument(
+                    GraphQLBoolean, default_value=False
+                )
+            },
             resolve=TypeFieldResolvers.input_fields,
         ),
         "ofType": GraphQLField(__Type, resolve=TypeFieldResolvers.of_type),
@@ -290,9 +295,11 @@ class TypeFieldResolvers:
     def fields(type_, _info, includeDeprecated=False):
         if is_object_type(type_) or is_interface_type(type_):
             items = type_.fields.items()
-            if not includeDeprecated:
-                return [item for item in items if not item[1].is_deprecated]
-            return list(items)
+            return (
+                list(items)
+                if includeDeprecated
+                else [item for item in items if item[1].deprecation_reason is None]
+            )
 
     @staticmethod
     def interfaces(type_, _info):
@@ -309,14 +316,22 @@ class TypeFieldResolvers:
     def enum_values(type_, _info, includeDeprecated=False):
         if is_enum_type(type_):
             items = type_.values.items()
-            if not includeDeprecated:
-                return [item for item in items if not item[1].is_deprecated]
-            return items
+            return (
+                items
+                if includeDeprecated
+                else [item for item in items if item[1].deprecation_reason is None]
+            )
 
+    # noinspection PyPep8Naming
     @staticmethod
-    def input_fields(type_, _info):
+    def input_fields(type_, _info, includeDeprecated=False):
         if is_input_object_type(type_):
-            return type_.fields.items()
+            items = type_.fields.items()
+            return (
+                items
+                if includeDeprecated
+                else [item for item in items if item[1].deprecation_reason is None]
+            )
 
     @staticmethod
     def of_type(type_, _info):
@@ -330,29 +345,62 @@ __Field: GraphQLObjectType = GraphQLObjectType(
     " and a return type.",
     fields=lambda: {
         "name": GraphQLField(
-            GraphQLNonNull(GraphQLString), resolve=lambda item, _info: item[0]
-        ),
-        "description": GraphQLField(
-            GraphQLString, resolve=lambda item, _info: item[1].description
+            GraphQLNonNull(GraphQLString), resolve=FieldResolvers.name
         ),
+        "description": GraphQLField(GraphQLString, resolve=FieldResolvers.description),
         "args": GraphQLField(
             GraphQLNonNull(GraphQLList(GraphQLNonNull(__InputValue))),
-            resolve=lambda item, _info: item[1].args.items(),
-        ),
-        "type": GraphQLField(
-            GraphQLNonNull(__Type), resolve=lambda item, _info: item[1].type
+            args={
+                "includeDeprecated": GraphQLArgument(
+                    GraphQLBoolean, default_value=False
+                )
+            },
+            resolve=FieldResolvers.args,
         ),
+        "type": GraphQLField(GraphQLNonNull(__Type), resolve=FieldResolvers.type),
         "isDeprecated": GraphQLField(
             GraphQLNonNull(GraphQLBoolean),
-            resolve=lambda item, _info: item[1].is_deprecated,
+            resolve=FieldResolvers.is_deprecated,
         ),
         "deprecationReason": GraphQLField(
-            GraphQLString, resolve=lambda item, _info: item[1].deprecation_reason
+            GraphQLString, resolve=FieldResolvers.deprecation_reason
         ),
     },
 )
 
 
+class FieldResolvers:
+    @staticmethod
+    def name(item, _info):
+        return item[0]
+
+    @staticmethod
+    def description(item, _info):
+        return item[1].description
+
+    # noinspection PyPep8Naming
+    @staticmethod
+    def args(item, _info, includeDeprecated=False):
+        items = item[1].args.items()
+        return (
+            items
+            if includeDeprecated
+            else [item for item in items if item[1].deprecation_reason is None]
+        )
+
+    @staticmethod
+    def type(item, _info):
+        return item[1].type
+
+    @staticmethod
+    def is_deprecated(item, _info):
+        return item[1].deprecation_reason is not None
+
+    @staticmethod
+    def deprecation_reason(item, _info):
+        return item[1].deprecation_reason
+
+
 __InputValue: GraphQLObjectType = GraphQLObjectType(
     name="__InputValue",
     description="Arguments provided to Fields or Directives and the input"
@@ -374,6 +422,13 @@ __InputValue: GraphQLObjectType = GraphQLObjectType(
             " the default value for this input value.",
             resolve=InputValueFieldResolvers.default_value,
         ),
+        "isDeprecated": GraphQLField(
+            GraphQLNonNull(GraphQLBoolean),
+            resolve=InputValueFieldResolvers.is_deprecated,
+        ),
+        "deprecationReason": GraphQLField(
+            GraphQLString, resolve=InputValueFieldResolvers.deprecation_reason
+        ),
     },
 )
 
@@ -399,6 +454,14 @@ class InputValueFieldResolvers:
         value_ast = ast_from_value(item[1].default_value, item[1].type)
         return print_ast(value_ast) if value_ast else None
 
+    @staticmethod
+    def is_deprecated(item, _info):
+        return item[1].deprecation_reason is not None
+
+    @staticmethod
+    def deprecation_reason(item, _info):
+        return item[1].deprecation_reason
+
 
 __EnumValue: GraphQLObjectType = GraphQLObjectType(
     name="__EnumValue",
@@ -415,7 +478,7 @@ __EnumValue: GraphQLObjectType = GraphQLObjectType(
         ),
         "isDeprecated": GraphQLField(
             GraphQLNonNull(GraphQLBoolean),
-            resolve=lambda item, _info: item[1].is_deprecated,
+            resolve=lambda item, _info: item[1].deprecation_reason is not None,
         ),
         "deprecationReason": GraphQLField(
             GraphQLString, resolve=lambda item, _info: item[1].deprecation_reason
