@@ -1,9 +1,8 @@
 from enum import Enum
-from operator import attrgetter
 from typing import Any, Dict, List, NamedTuple, Union, cast
 
-from ..language import print_ast, visit, Visitor
-from ..pyutils import inspect, Undefined
+from ..language import print_ast, visit, ObjectValueNode, Visitor
+from ..pyutils import inspect, natural_comparison_key, FrozenList, Undefined
 from ..type import (
     GraphQLEnumType,
     GraphQLField,
@@ -557,13 +556,18 @@ def stringify_value(value: Any, type_: GraphQLInputType) -> str:
     if ast is None:  # pragma: no cover
         raise TypeError(f"Invalid value: {inspect(value)}")
 
-    # noinspection PyMethodMayBeStatic
     class SortVisitor(Visitor):
-        def enter_object_value(self, object_node, *_args):
-            object_node.fields = sorted(
-                object_node.fields, key=attrgetter("name.value")
+        @staticmethod
+        def enter_object_value(
+            object_value_node: ObjectValueNode, *_args: Any
+        ) -> ObjectValueNode:
+            object_value_node.fields = FrozenList(
+                sorted(
+                    object_value_node.fields,
+                    key=lambda node: natural_comparison_key(node.name.value),
+                )
             )
-            return object_node
+            return object_value_node
 
     sorted_ast = visit(ast, SortVisitor())
 
