@@ -14,9 +14,10 @@ IntrospectionSchema = Dict[str, Any]
 def introspection_from_schema(
     schema: GraphQLSchema,
     descriptions: bool = True,
-    specified_by_url: bool = False,
+    specified_by_url: bool = True,
     directive_is_repeatable: bool = True,
     schema_description: bool = True,
+    input_value_deprecation: bool = True,
 ) -> IntrospectionSchema:
     """Build an IntrospectionQuery from a GraphQLSchema
 
@@ -28,13 +29,17 @@ def introspection_from_schema(
     """
     document = parse(
         get_introspection_query(
-            descriptions, specified_by_url, directive_is_repeatable, schema_description
+            descriptions,
+            specified_by_url,
+            directive_is_repeatable,
+            schema_description,
+            input_value_deprecation,
         )
     )
 
-    from ..execution.execute import execute, ExecutionResult
+    from ..execution.execute import execute_sync, ExecutionResult
 
-    result = execute(schema, document)
+    result = execute_sync(schema, document)
     if not isinstance(result, ExecutionResult):  # pragma: no cover
         raise RuntimeError("Introspection cannot be executed")
     if result.errors:  # pragma: no cover
